
from optparse import OptionParser, OptionGroup
import importlib
from exceptions import ImportError, OSError
import matplotlib.pyplot as plt
from example_utils import *
import os
from time import strftime
import time




'''
Topic: Picoscope AC Coupling error with SDK & Python

Using Picosdk from https://github.com/picotech/picosdk-python-examples/tree/master/picosdk



Picoscope : 5444B
  Connect following ports on Picoscope directly:
    AWG:GEN  <---> Osci CH:A
AWG is generating a sine wave with pk2pk of 200mV, with a offset of 1V

Goal: Measure this signal AC-Coupled

'''

d = 'ps5000a'
module = importlib.import_module("picosdk.%s" % d)
units = module.enumerate_units()
ps = module.Device()
status = ps.open_unit(serial= None)
if status != st.pico_num("PICO_OK"):
    p_error("Device open failed with %s" % (st.pico_tag(status)))
p_info("Device connected: %s %s" % (ps.info.variant_info, ps.info.batch_and_serial))
p_info("Driver: %s" % ps.info.driver_version)
p_info("Firmware: %s/%s" % (ps.info.firmware_version_1, ps.info.firmware_version_2))
channels = [0]
ps.set_device_resolution(4)#16bit




ret = ps.set_simple_trigger(enabled=False, 
                            source=0, 
                            threshold=0,
                            direction=0, 
                            delay=0, 
                            waitfor=0)
error_check("Trigger setup", ret)
                                        



dev_channels = (0, 1, 2, 3)
for c in dev_channels:
    status, state = ps.get_channel_state(channel=c)
    state.range = 7 #+-2V
    state.coupling = 0 # default = 1 = DC  , 0=AC
    state.enabled = c in channels
    error_check("Channel %s Setup" % ps.m.Channels.labels[c], ps.set_channel(channel=c, state=state))
    
error_check("Siggen setup", ps.set_simple_sig_gen(wave_type=ps.m.WaveTypes.sine,
                                                              frequency=10000,
                                                              pk2pk=2*100*1000, 
                                                              offset=1000*1000))
time.sleep(1)                 
status, max_samples = ps.set_memory_segments(1)
error_check("Segments setup", status)

                  
status, buffers = ps.locate_buffer(channel=0, 
                                   samples=10000,
                                   segment=0, 
                                   mode=0, 
                                   downsample=1)
error_check("Buffer chan %s mode %s ratio %d on segment %d setup"
             % (ps.m.Channels.labels[0], ps.m.RatioModes.labels[0], 1, 0), status)


for i in range(2):
    ret = ps.collect_segment(segment=0, interval=29.999999999999996, overlapped=False)  #  calls runblock  internally
    error_check("Collection start", ret)

    s = 0
    c = 1
    m = 0
    status, info = ps.get_buffer_info(0)
    status, data = ps.get_buffer_data(0)
    data = data * ( 4.0/65536)
    plt.plot(data)
    if i == 0:
        plt.title('This run is not correctly AC Coupled')
    elif i == 1:
        plt.title('This run now is correctly AC Coupled')

    plt.show()
pass